#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
###
# Application: wah!cade
# File:        emulators.py
# Description: emulator class for wah!cade
# Copyright (c) 2007  Sylvain Faveau
###
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
import os
import glob

#project modules
from mamewah_ini import MameWahIni

class Emulators:
    def __init__(self, config_dir):
        #build list of emulators
        emu_list = []
        emu_ini_files = glob.glob(os.path.join(config_dir, 'ini', '*[!0-9].ini'))
        for emu_ini in emu_ini_files:
            ini = MameWahIni(emu_ini)
            emu_list.append(
                [ini.get('emulator_title'),
                os.path.splitext(os.path.basename(emu_ini))[0]])
        emu_list.sort()
        self.emu_name = [e[1] for e in emu_list]
        self.emu_list = emu_list

    def next(self, current_emu):
        emu_idx = self.emu_name.index(current_emu)
        idx = (emu_idx + 1) % len(self.emu_list)
        return self.emu_list[idx][1]

    def previous(self, current_emu):
        emu_idx = self.emu_name.index(current_emu)
        idx = (emu_idx - 1) % len(self.emu_list)
        return self.emu_list[idx][1]

    def __getitem__(self, item):
        return self.emu_list[item]

    def __iter__(self):
        return iter(self.emu_list)

    def __len__(self):
        return len(self.emu_list)

if __name__ == '__main__':
    emulators = Emulators('config.dist')
    print len(emulators), ' emulators found.'
    print '='*25
    for emulator in emulators:
        print '  ', emulator
    current = emulators[0][1]
    print 'current emulator ', current
    for i in range(4):
        print '  next():',
        current = emulators.next(current)
        print 'current emulator ', current
    current = emulators[0][1]
    print 'current emulator ', current
    for i in range(4):
        print '  previous():',
        current = emulators.previous(current)
        print 'current emulator ', current
